var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __reExport = (target, mod, secondTarget) => (__copyProps(target, mod, "default"), secondTarget && __copyProps(secondTarget, mod, "default"));

// node_modules/@girs/gnome-shell/dist/extensions/extension.js
var extension_exports = {};
__reExport(extension_exports, extension_star);
import * as extension_star from "resource:///org/gnome/shell/extensions/extension.js";

// src/Utils.ts
var Utils = class {
  static UUID = "quick-lofi@eucaue";
  static ICONS = {
    INDICATOR_DEFAULT: "/icon-symbolic.svg",
    INDICATOR_PLAYING: "/icon-playing-symbolic.svg",
    POPUP_PLAY: "media-playback-start-symbolic",
    POPUP_PAUSE: "media-playback-stop-symbolic"
  };
  static getExtension() {
    return extension_exports.Extension.lookupByUUID(this.UUID);
  }
  static getSettings() {
    return this.getExtension().getSettings();
  }
  static debug(...message) {
    console.log("[ QUICK LOFI DEBUG ] >>> ", ...message);
  }
};

// src/Player.ts
import GLib from "gi://GLib";
import Gio2 from "gi://Gio";
import * as Main from "resource:///org/gnome/shell/ui/main.js";
var Player = class {
  isPlaying = false;
  _process = null;
  _mpvSocket = "/tmp/quicklofi-socket";
  _settings = Utils.getSettings();
  _isCommandRunning = false;
  init() {
    this._settings.connect("changed::volume", (settings, key) => {
      if (this._process !== null && !this._isCommandRunning) {
        const volume = settings.get_int(key);
        const command = this.createCommand({
          command: ["set_property", "volume", volume]
        });
        this.sendCommandToMpvSocket(command);
      }
    });
  }
  stopPlayer() {
    if (this._process !== null) {
      this._process.force_exit();
      this.isPlaying = false;
      this._process = null;
      return;
    }
  }
  startPlayer(radio) {
    this.stopPlayer();
    try {
      this.isPlaying = true;
      this._process = Gio2.Subprocess.new(
        [
          "mpv",
          radio.radioUrl,
          `--volume=${this._settings.get_int("volume")}`,
          `--input-ipc-server=${this._mpvSocket}`,
          "--no-video"
        ],
        Gio2.SubprocessFlags.NONE
      );
    } catch (e) {
      this.isPlaying = false;
      this._process = null;
      Main.notifyError(
        "MPV not found",
        "Did you have mpv installed?\nhttps://github.com/EuCaue/quick-lofi?tab=readme-ov-file#dependencies"
      );
    }
  }
  createCommand(command) {
    const cmd = `echo '${JSON.stringify(command)}'`;
    return cmd;
  }
  sendCommandToMpvSocket(mpvCommand) {
    this._isCommandRunning = true;
    const socatCommand = ["|", "socat", "-", this._mpvSocket];
    const [success, _] = GLib.spawn_async(
      null,
      ["/bin/sh", "-c", mpvCommand + " " + socatCommand.join(" ")],
      null,
      GLib.SpawnFlags.SEARCH_PATH,
      null
    );
    this._isCommandRunning = false;
    if (!success) {
      Main.notifyError(
        "Socat not found",
        "Did you have socat installed?\nhttps://github.com/EuCaue/quick-lofi?tab=readme-ov-file#dependencies"
      );
    }
  }
};

// src/extension.ts
import GObject from "gi://GObject";
import Gio3 from "gi://Gio";
import St from "gi://St";
import { Extension as Extension2 } from "resource:///org/gnome/shell/extensions/extension.js";
import * as Main2 from "resource:///org/gnome/shell/ui/main.js";
import * as PanelMenu from "resource:///org/gnome/shell/ui/panelMenu.js";
import * as PopupMenu from "resource:///org/gnome/shell/ui/popupMenu.js";
var _Indicator = class _Indicator extends PanelMenu.Button {
  mpvPlayer = new Player();
  _radios;
  _settings = Utils.getSettings();
  _icon;
  _activeRadioPopupItem = null;
  constructor() {
    super(0, "Quick Lofi");
    this.mpvPlayer = new Player();
    this.mpvPlayer.init();
    this._radios = [];
    const gicon = Gio3.icon_new_for_string(Utils.getExtension().path + Utils.ICONS.INDICATOR_DEFAULT);
    this._icon = new St.Icon({
      gicon,
      styleClass: "system-status-icon",
      iconSize: 20
    });
    this.add_child(this._icon);
    this._connectSettingsChangedEvent();
  }
  _createRadios() {
    const radios = Utils.getSettings().get_strv("radios");
    radios.forEach((entry) => {
      const [radioName, radioUrl] = entry.split(" - ");
      this._radios.push({ radioName, radioUrl });
    });
  }
  _connectSettingsChangedEvent() {
    this._settings = Utils.getSettings();
    this._settings.connect("changed", (_, key) => {
      Utils.debug("VRUM");
      if (key === "radios") {
        this._updateMenuItems();
      }
    });
    this._createRadios();
  }
  _updateIcon(playing) {
    const extPath = Utils.getExtension().path;
    const iconPath = `${extPath}/${playing ? Utils.ICONS.INDICATOR_PLAYING : Utils.ICONS.INDICATOR_DEFAULT}`;
    const gicon = Gio3.icon_new_for_string(iconPath);
    this._icon.set_gicon(gicon);
  }
  _togglePlayingStatus(child) {
    const currentRadio = this._radios.find((radio) => radio.radioName === child.label.text);
    if (child === this._activeRadioPopupItem) {
      this.mpvPlayer.stopPlayer();
      this._activeRadioPopupItem.setIcon(Gio3.icon_new_for_string(Utils.ICONS.POPUP_PLAY));
      this._activeRadioPopupItem = null;
      this._updateIcon(false);
    } else {
      if (this._activeRadioPopupItem) {
        this._activeRadioPopupItem.setIcon(Gio3.icon_new_for_string(Utils.ICONS.POPUP_PLAY));
        this._updateIcon(false);
      }
      this.mpvPlayer.startPlayer(currentRadio);
      this._activeRadioPopupItem = child;
      child.setIcon(Gio3.icon_new_for_string(Utils.ICONS.POPUP_PAUSE));
      this._updateIcon(true);
    }
  }
  _handleButtonClick() {
    this.connect("button-press-event", (_, event) => {
      const RIGHT_CLICK = 3;
      if (event.get_button() === RIGHT_CLICK) {
        this.menu.close(false);
        Utils.getExtension().openPreferences();
        return;
      }
    });
  }
  _updateMenuItems() {
    this.menu.box.remove_all_children();
    this._radios = [];
    this._createRadios();
    this._createMenuItems();
  }
  _createMenuItems() {
    const scrollView = new St.ScrollView();
    const section1 = new PopupMenu.PopupMenuSection();
    scrollView.add_actor(section1.actor);
    this._radios.forEach((radio) => {
      const menuItem = new PopupMenu.PopupImageMenuItem(
        radio.radioName,
        Gio3.icon_new_for_string(Utils.ICONS.POPUP_PLAY)
      );
      menuItem.connect("activate", this._togglePlayingStatus.bind(this));
      section1.addMenuItem(menuItem);
    });
    this.menu.box.add_child(scrollView);
    this.menu.box.style = `
        max-height: 13em;
    `;
  }
  _init() {
    this._radios = [];
    this._createRadios();
    super._init(0, "Quick Lofi");
    this._createMenuItems();
    this._handleButtonClick();
  }
};
GObject.registerClass(_Indicator);
var Indicator = _Indicator;
var QuickLofi = class extends Extension2 {
  _indicator = null;
  _removeIndicator() {
    const isUserMode = Main2.sessionMode.currentMode === "user" || Main2.sessionMode.parentMode === "user";
    if (this._indicator && isUserMode) {
      Utils.debug("extension disabled");
      this._indicator.mpvPlayer.stopPlayer();
      this._indicator.destroy();
      this._indicator = null;
    }
  }
  enable() {
    if (this._indicator === null) {
      Utils.debug("extension enabled");
      this._indicator = new Indicator();
      Main2.panel.addToStatusArea(this.uuid, this._indicator);
    }
  }
  disable() {
    this._removeIndicator();
  }
};
export {
  QuickLofi as default
};
