// node_modules/@girs/gtk-4.0/gtk-4.0.js
import Gtk from "gi://Gtk?version=4.0";
var gtk_4_0_default = Gtk;

// src/prefs.ts
import Gtk2 from "gi://Gtk";
import Adw from "gi://Adw";
import Gio from "gi://Gio";
import GLib from "gi://GLib";
import { ExtensionPreferences, gettext as _ } from "resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js";
var GnomeRectanglePreferences = class extends ExtensionPreferences {
  _settings;
  _radios = [];
  _addRadio(radioName, radioUrl) {
    this._radios.push(`${radioName} - ${radioUrl}`);
    this._settings.set_strv("radios", this._radios);
  }
  _handleErrorRadioRow(radioRow, errorMessage) {
    const TIMEOUT_SECONDS = 3;
    const currentRadioRowTitle = radioRow.get_title();
    radioRow.add_css_class("error");
    radioRow.set_title(errorMessage);
    GLib.timeout_add_seconds(GLib.PRIORITY_HIGH, TIMEOUT_SECONDS, () => {
      radioRow.set_title(currentRadioRowTitle);
      radioRow.remove_css_class("error");
      return GLib.SOURCE_REMOVE;
    });
  }
  _populateRadios(radiosGroup) {
    for (let i = 0; i < this._radios.length; i++) {
      const [radioName, radioUrl] = this._radios[i].split(" - ");
      const radiosExpander = new Adw.ExpanderRow({ title: _(radioName) });
      const nameRadioRow = new Adw.EntryRow({
        title: _("Radio Name"),
        text: _(radioName),
        showApplyButton: true
      });
      const urlRadioRow = new Adw.EntryRow({ title: _("Radio Name"), text: _(radioUrl), showApplyButton: true });
      const removeButton = new gtk_4_0_default.Button({
        label: `Remove ${radioName}`,
        iconName: "user-trash-symbolic",
        halign: Gtk2.Align.CENTER,
        valign: Gtk2.Align.CENTER
      });
      removeButton.connect("clicked", () => {
        const messsageDialog = new gtk_4_0_default.MessageDialog({
          text: _(`Are you sure you want to delete ${radioName} ?`),
          destroyWithParent: true,
          modal: true,
          visible: true,
          buttons: gtk_4_0_default.ButtonsType.OK_CANCEL
        });
        messsageDialog.connect("response", (_2, response) => {
          if (response === gtk_4_0_default.ResponseType.OK) {
            this._removeRadio(i);
            this._reloadRadios(radiosGroup);
          }
          messsageDialog.destroy();
        });
      });
      nameRadioRow.connect("apply", (w) => {
        if (w.text.length < 2) {
          this._handleErrorRadioRow(w, "Name must be at least 2 characters");
          w.set_text(radioName);
          return;
        }
        const index = this._radios.findIndex((entry) => entry.startsWith(radioName));
        this._updateRadio(index, "radioName", w.text);
        radiosExpander.set_title(w.text);
      });
      urlRadioRow.connect("apply", (w) => {
        try {
          GLib.uri_is_valid(w.text, GLib.UriFlags.NONE);
          const index = this._radios.findIndex((entry) => entry.startsWith(radioName));
          this._updateRadio(index, "radioUrl", w.text);
        } catch (e) {
          this._handleErrorRadioRow(w, "Invalid URL");
          w.set_text(radioUrl);
        }
      });
      radiosExpander.add_row(nameRadioRow);
      radiosExpander.add_row(urlRadioRow);
      radiosExpander.add_row(removeButton);
      radiosGroup.add(radiosExpander);
    }
  }
  _reloadRadios(radiosGroup) {
    let index = 0;
    const l = this._radios.length;
    while (l >= index) {
      const child = radiosGroup.get_first_child().get_first_child().get_next_sibling().get_first_child().get_first_child();
      if (child === null)
        break;
      radiosGroup.remove(child);
      index++;
    }
    this._populateRadios(radiosGroup);
  }
  _removeRadio(index) {
    this._radios.splice(index, 1);
    this._settings.set_strv("radios", this._radios);
  }
  _updateRadio(index, field, content) {
    if (index !== -1) {
      const radio = this._radios[index];
      const [radioName, radioUrl] = radio.split(" - ");
      if (field === "radioUrl") {
        this._radios[index] = `${radioName} - ${content}`;
      }
      if (field === "radioName") {
        this._radios[index] = `${content} - ${radioUrl}`;
      }
      this._settings.set_strv("radios", this._radios);
      return true;
    }
    return false;
  }
  fillPreferencesWindow(window) {
    this._settings = this.getSettings();
    this._radios = this._settings.get_strv("radios");
    const page = new Adw.PreferencesPage({
      title: _("General"),
      icon_name: "dialog-information-symbolic"
    });
    const volumeGroup = new Adw.PreferencesGroup({
      title: _("Player Settings"),
      description: _("Configure the player settings")
    });
    page.add(volumeGroup);
    const volumeLevel = new Adw.SpinRow({
      title: _("Volume"),
      subtitle: _("Volume to set when playing lofi"),
      adjustment: new Gtk2.Adjustment({
        lower: 0,
        upper: 100,
        step_increment: 1
      })
    });
    volumeGroup.add(volumeLevel);
    const radiosGroup = new Adw.PreferencesGroup({
      title: _("Radios Settings"),
      description: _("Configure the radio list")
    });
    this._populateRadios(radiosGroup);
    const addRadioGroup = new Adw.PreferencesGroup({
      title: _("Add Radio to the list")
    });
    const nameRadioRow = new Adw.EntryRow({ title: _("Radio Name") });
    const urlRadioRow = new Adw.EntryRow({ title: _("Radio URL") });
    const addButton = new gtk_4_0_default.Button({
      label: _("Add Radio"),
      iconName: "list-add-symbolic",
      halign: Gtk2.Align.CENTER,
      valign: Gtk2.Align.CENTER,
      marginTop: 10
    });
    addButton.connect("clicked", () => {
      try {
        GLib.uri_is_valid(urlRadioRow.text, GLib.UriFlags.NONE);
        if (nameRadioRow.text.length < 2) {
          this._handleErrorRadioRow(nameRadioRow, "Name must be at least 2 characters");
          return;
        }
        this._addRadio(nameRadioRow.text, urlRadioRow.text);
        nameRadioRow.set_text("");
        urlRadioRow.set_text("");
        this._reloadRadios(radiosGroup);
      } catch (e) {
        this._handleErrorRadioRow(urlRadioRow, "Invalid URL");
        if (nameRadioRow.text.length < 2) {
          this._handleErrorRadioRow(nameRadioRow, "Name must be at least 2 characters");
        }
      }
    });
    addRadioGroup.add(nameRadioRow);
    addRadioGroup.add(urlRadioRow);
    addRadioGroup.add(addButton);
    page.add(radiosGroup);
    page.add(addRadioGroup);
    window.add(page);
    this._settings.bind("volume", volumeLevel, "value", Gio.SettingsBindFlags.DEFAULT);
  }
};
export {
  GnomeRectanglePreferences as default
};
